defmodule Nulla.MediaAttachments do
  @moduledoc """
  The MediaAttachments context.
  """

  import Ecto.Query, warn: false
  alias Nulla.Repo

  alias Nulla.MediaAttachments.MediaAttachment

  @doc """
  Returns the list of media_attachments.

  ## Examples

      iex> list_media_attachments()
      [%MediaAttachment{}, ...]

  """
  def list_media_attachments do
    Repo.all(MediaAttachment)
  end

  @doc """
  Gets a single media_attachment.

  Raises `Ecto.NoResultsError` if the Media attachment does not exist.

  ## Examples

      iex> get_media_attachment!(123)
      %MediaAttachment{}

      iex> get_media_attachment!(456)
      ** (Ecto.NoResultsError)

  """
  def get_media_attachment!(id), do: Repo.get!(MediaAttachment, id)

  @doc """
  Creates a media_attachment.

  ## Examples

      iex> create_media_attachment(%{field: value})
      {:ok, %MediaAttachment{}}

      iex> create_media_attachment(%{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def create_media_attachment(attrs \\ %{}) do
    %MediaAttachment{}
    |> MediaAttachment.changeset(attrs)
    |> Repo.insert()
  end

  @doc """
  Updates a media_attachment.

  ## Examples

      iex> update_media_attachment(media_attachment, %{field: new_value})
      {:ok, %MediaAttachment{}}

      iex> update_media_attachment(media_attachment, %{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def update_media_attachment(%MediaAttachment{} = media_attachment, attrs) do
    media_attachment
    |> MediaAttachment.changeset(attrs)
    |> Repo.update()
  end

  @doc """
  Deletes a media_attachment.

  ## Examples

      iex> delete_media_attachment(media_attachment)
      {:ok, %MediaAttachment{}}

      iex> delete_media_attachment(media_attachment)
      {:error, %Ecto.Changeset{}}

  """
  def delete_media_attachment(%MediaAttachment{} = media_attachment) do
    Repo.delete(media_attachment)
  end

  @doc """
  Returns an `%Ecto.Changeset{}` for tracking media_attachment changes.

  ## Examples

      iex> change_media_attachment(media_attachment)
      %Ecto.Changeset{data: %MediaAttachment{}}

  """
  def change_media_attachment(%MediaAttachment{} = media_attachment, attrs \\ %{}) do
    MediaAttachment.changeset(media_attachment, attrs)
  end
end
