defmodule Nulla.Notes.Note do
  use Ecto.Schema
  import Ecto.Changeset
  alias Nulla.Snowflake
  alias Nulla.Actors
  alias Nulla.Actors.Actor
  alias Nulla.MediaAttachments.MediaAttachment

  @primary_key {:id, :integer, autogenerate: false}
  schema "notes" do
    field :ap_id, :string
    field :inReplyTo, :string
    field :published, :utc_datetime
    field :url, :string
    field :visibility, :string
    field :to, {:array, :string}
    field :cc, {:array, :string}
    field :sensitive, :boolean, default: false
    field :content, :string
    field :tag, {:array, :map}
    field :language, :string
    field :featured, :boolean, default: false

    belongs_to :actor, Actor
    has_many :media_attachments, MediaAttachment

    timestamps(type: :utc_datetime)
  end

  @doc false
  def changeset(note, attrs) do
    note
    |> cast(attrs, [
      :ap_id,
      :inReplyTo,
      :published,
      :url,
      :visibility,
      :to,
      :cc,
      :sensitive,
      :content,
      :tag,
      :language,
      :featured,
      :actor_id
    ])
    |> maybe_put_id()
    |> maybe_put_ap_id()
    |> validate_required([
      :ap_id,
      :published,
      :url,
      :visibility,
      :to,
      :cc,
      :content,
      :tag,
      :language,
      :featured,
      :actor_id
    ])
  end

  defp maybe_put_id(changeset) do
    id = get_field(changeset, :id)

    if is_nil(id) do
      change(changeset, id: Snowflake.next_id())
    else
      changeset
    end
  end

  defp maybe_put_ap_id(changeset) do
    id = get_field(changeset, :id)
    ap_id = get_field(changeset, :ap_id)
    actor_id = get_field(changeset, :actor_id)

    cond do
      not is_nil(ap_id) ->
        changeset

      is_nil(actor_id) or is_nil(id) ->
        changeset

      true ->
        actor = Actors.get_actor!(actor_id)
        change(changeset, ap_id: "#{actor.ap_id}/notes/#{id}")
    end
  end
end
