defmodule NullaWeb.Router do
  use NullaWeb, :router

  import NullaWeb.UserAuth

  pipeline :browser do
    plug :accepts, ["html"]
    plug :fetch_session
    plug :fetch_live_flash
    plug :put_root_layout, html: {NullaWeb.Layouts, :root}
    plug :protect_from_forgery
    plug :put_secure_browser_headers
    plug :fetch_current_user
  end

  pipeline :api do
    plug :accepts, ["json"]
    plug :fetch_api_user
  end

  pipeline :activitypub do
    plug :accepts, ["activity+json"]
  end

  scope "/", NullaWeb do
    pipe_through [:browser, :redirect_if_user_is_authenticated]

    live_session :redirect_if_user_is_authenticated,
      on_mount: [{NullaWeb.UserAuth, :redirect_if_user_is_authenticated}] do
      live "/users/register", UserRegistrationLive, :new
      live "/users/log_in", UserLoginLive, :new
      live "/users/reset_password", UserForgotPasswordLive, :new
      live "/users/reset_password/:token", UserResetPasswordLive, :edit
    end

    post "/users/log_in", UserSessionController, :create
  end

  scope "/", NullaWeb do
    pipe_through [:browser, :require_authenticated_user]

    live_session :require_authenticated_user,
      on_mount: [{NullaWeb.UserAuth, :ensure_authenticated}] do
      live "/users/settings", UserSettingsLive, :edit
      live "/users/settings/confirm_email/:token", UserSettingsLive, :confirm_email
    end
  end

  scope "/", NullaWeb do
    pipe_through [:browser]

    delete "/users/log_out", UserSessionController, :delete

    live_session :current_user,
      on_mount: [{NullaWeb.UserAuth, :mount_current_user}] do
      live "/users/confirm/:token", UserConfirmationLive, :edit
      live "/users/confirm", UserConfirmationInstructionsLive, :new
    end
  end

  scope "/", NullaWeb do
    pipe_through :browser

    get "/", PageController, :home
  end

  scope "/api", NullaWeb.Api, as: :api do
    pipe_through :api

    resources "/actors", ActorController, except: [:new, :edit]
    resources "/notes", NoteController, except: [:new, :edit]
    resources "/media_attachments", MediaAttachmentController, except: [:new, :edit]
    resources "/relations", RelationController, except: [:new, :edit]
    resources "/likes", LikeController, except: [:new, :edit]
    resources "/announces", AnnounceController, except: [:new, :edit]
    resources "/activities", ActivityController, except: [:new, :edit]
  end

  scope "/", NullaWeb.ActivityPub, as: :activitypub do
    pipe_through :activitypub

    post "/inbox", InboxController, :inbox

    scope "/users/:username" do
      get "/", ActorController, :show
      get "/following", FollowController, :following
      get "/followers", FollowController, :followers
      post "/inbox", InboxController, :inbox
      get "/outbox", OutboxController, :index
      get "/collections/featured", FeaturedController, :index
      get "/notes/:id", NoteController, :show
    end
  end

  scope "/", NullaWeb.Generic, as: :generic do
    get "/.well-known/host-meta", HostmetaController, :index
    get "/.well-known/webfinger", WebfingerController, :index
    get "/.well-known/nodeinfo", NodeinfoController, :index
    get "/nodeinfo/2.0", NodeinfoController, :show
  end

  # Enable LiveDashboard and Swoosh mailbox preview in development
  if Application.compile_env(:nulla, :dev_routes) do
    # If you want to use the LiveDashboard in production, you should put
    # it behind authentication and allow only admins to access it.
    # If your application does not have an admins-only section yet,
    # you can use Plug.BasicAuth to set up some basic authentication
    # as long as you are also using SSL (which you should anyway).
    import Phoenix.LiveDashboard.Router

    scope "/dev" do
      pipe_through :browser

      live_dashboard "/dashboard", metrics: NullaWeb.Telemetry
      forward "/mailbox", Plug.Swoosh.MailboxPreview
    end
  end
end
